@@ -158,19 +158,23 @@ plot_filler <- yulab.utils::get_fun_from_pkg("patchwork", "plot_filler")
 ##' @export
 ##' @author Guangchuang Yu
 gglist <- function(gglist, ...) {
-    res <- gglist
+    res <- .process_plotlist(gglist)
     attr(res, 'params') <- list(...)
     res <- structure(res,
         class = c("gglist", "list")
     )
 
-    idx <- vapply(res, function(p) inherits(p, 'enrichplotDot'), FUN.VALUE=logical(1))
-    if (any(idx)) {
-        res[idx] <- lapply(res[idx], ggfun::set_point_legend_shape)
-    }
     return(res)
 }
 
+.process_plotlist <- function(plotlist) {
+    idx <- vapply(plotlist, function(p) inherits(p, 'enrichplotDot'), FUN.VALUE=logical(1))
+    if (any(idx)) {
+        plotlist[idx] <- lapply(plotlist[idx], ggfun::set_point_legend_shape)
+    }
+    return(plotlist)
+}
+
 ##' @method print gglist
 ##' @export
 print.gglist <- function(x, ...) {
